summaryrefslogtreecommitdiffstats
path: root/kopete/libkopete/kopeteawaydialog.h
diff options
context:
space:
mode:
Diffstat (limited to 'kopete/libkopete/kopeteawaydialog.h')
-rw-r--r--kopete/libkopete/kopeteawaydialog.h5
1 files changed, 3 insertions, 2 deletions
diff --git a/kopete/libkopete/kopeteawaydialog.h b/kopete/libkopete/kopeteawaydialog.h
index 517e419c..1c494e60 100644
--- a/kopete/libkopete/kopeteawaydialog.h
+++ b/kopete/libkopete/kopeteawaydialog.h
@@ -53,14 +53,15 @@ class KopeteAwayDialogPrivate;
class KOPETE_EXPORT KopeteAwayDialog : public KDialogBase
{
Q_OBJECT
+ TQ_OBJECT
public:
/**
* Constructor for the Away Dialog
* @param parent The object that owns this
* @param name Name for this object
*/
- KopeteAwayDialog( TQWidget *parent = 0, const char *name = 0 );
+ KopeteAwayDialog( TQWidget *tqparent = 0, const char *name = 0 );
/**
* Destructor
@@ -53,14 +53,15 @@ class KopeteAwayDialogPrivate;
/**
* Constructor for the Away Dialog
- * @param parent The object that owns this
+ * @param tqparent The object that owns this
* @param name Name for this object
*/